@@ -1,7 +1,7 @@
 name = "pybis"
-__author__ = "Swen Vermeul"
+__author__ = "Swen Vermeul • ID SIS • ETH Zürich"
 __email__ = "swen@ethz.ch"
-__version__ = "1.32.0"
+__version__ = "1.33.2"
 
 from . import pybis
 from .pybis import DataSet
